Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2252)

Unified Diff: chrome/browser/webdata/autofill_profile_syncable_service.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/webdata/autofill_profile_syncable_service.h
diff --git a/chrome/browser/webdata/autofill_profile_syncable_service.h b/chrome/browser/webdata/autofill_profile_syncable_service.h
index 2da706cacac9b19205e93a2e96ba699a17d154d2..81f4f833477be4627432e927cadeec5738976f86 100644
--- a/chrome/browser/webdata/autofill_profile_syncable_service.h
+++ b/chrome/browser/webdata/autofill_profile_syncable_service.h
@@ -38,7 +38,7 @@ extern const char kAutofillProfileTag[];
// local->cloud syncs. Then for each cloud change we receive
// ProcessSyncChanges() and for each local change Observe() is called.
class AutofillProfileSyncableService
- : public SyncableService,
+ : public csync::SyncableService,
public content::NotificationObserver,
public base::NonThreadSafe {
public:
@@ -47,17 +47,18 @@ class AutofillProfileSyncableService
static syncable::ModelType model_type() { return syncable::AUTOFILL_PROFILE; }
- // SyncableService implementation.
- virtual SyncError MergeDataAndStartSyncing(
+ // csync::SyncableService implementation.
+ virtual csync::SyncError MergeDataAndStartSyncing(
syncable::ModelType type,
- const SyncDataList& initial_sync_data,
- scoped_ptr<SyncChangeProcessor> sync_processor,
- scoped_ptr<SyncErrorFactory> sync_error_factory) OVERRIDE;
+ const csync::SyncDataList& initial_sync_data,
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor,
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory) OVERRIDE;
virtual void StopSyncing(syncable::ModelType type) OVERRIDE;
- virtual SyncDataList GetAllSyncData(syncable::ModelType type) const OVERRIDE;
- virtual SyncError ProcessSyncChanges(
+ virtual csync::SyncDataList GetAllSyncData(
+ syncable::ModelType type) const OVERRIDE;
+ virtual csync::SyncError ProcessSyncChanges(
const tracked_objects::Location& from_here,
- const SyncChangeList& change_list) OVERRIDE;
+ const csync::SyncChangeList& change_list) OVERRIDE;
// content::NotificationObserver implementation.
virtual void Observe(int type,
@@ -122,13 +123,15 @@ class AutofillProfileSyncableService
// found substitutes it for the new one, otherwise adds a new profile. Returns
// iterator pointing to added/updated profile.
GUIDToProfileMap::iterator CreateOrUpdateProfile(
- const SyncData& data, GUIDToProfileMap* profile_map, DataBundle* bundle);
+ const csync::SyncData& data,
+ GUIDToProfileMap* profile_map,
+ DataBundle* bundle);
// Syncs |change| to the cloud.
void ActOnChange(const AutofillProfileChange& change);
- // Creates SyncData based on supplied |profile|.
- static SyncData CreateData(const AutofillProfile& profile);
+ // Creates csync::SyncData based on supplied |profile|.
+ static csync::SyncData CreateData(const AutofillProfile& profile);
AutofillTable* GetAutofillTable() const;
@@ -151,7 +154,7 @@ class AutofillProfileSyncableService
// For unit-tests.
AutofillProfileSyncableService();
- void set_sync_processor(SyncChangeProcessor* sync_processor) {
+ void set_sync_processor(csync::SyncChangeProcessor* sync_processor) {
sync_processor_.reset(sync_processor);
}
@@ -163,9 +166,9 @@ class AutofillProfileSyncableService
ScopedVector<AutofillProfile> profiles_;
GUIDToProfileMap profiles_map_;
- scoped_ptr<SyncChangeProcessor> sync_processor_;
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor_;
- scoped_ptr<SyncErrorFactory> sync_error_factory_;
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory_;
DISALLOW_COPY_AND_ASSIGN(AutofillProfileSyncableService);
};
« no previous file with comments | « chrome/browser/webdata/autocomplete_syncable_service.cc ('k') | chrome/browser/webdata/autofill_profile_syncable_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698